# This file is generated by objective.metadata
#
# Last update: Sun Jul 11 21:37:11 2021
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a


else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$EKErrorDomain$EKEventStoreChangedNotification$"""
enums = """$EKAlarmProximityEnter@1$EKAlarmProximityLeave@2$EKAlarmProximityNone@0$EKAlarmTypeAudio@1$EKAlarmTypeDisplay@0$EKAlarmTypeEmail@3$EKAlarmTypeProcedure@2$EKAuthorizationStatusAuthorized@3$EKAuthorizationStatusDenied@2$EKAuthorizationStatusNotDetermined@0$EKAuthorizationStatusRestricted@1$EKCalendarEventAvailabilityBusy@1$EKCalendarEventAvailabilityFree@2$EKCalendarEventAvailabilityNone@0$EKCalendarEventAvailabilityTentative@4$EKCalendarEventAvailabilityUnavailable@8$EKCalendarTypeBirthday@4$EKCalendarTypeCalDAV@1$EKCalendarTypeExchange@2$EKCalendarTypeLocal@0$EKCalendarTypeSubscription@3$EKEntityMaskEvent@1$EKEntityMaskReminder@2$EKEntityTypeEvent@0$EKEntityTypeReminder@1$EKErrorAlarmGreaterThanRecurrence@8$EKErrorAlarmProximityNotSupported@21$EKErrorCalendarDoesNotAllowEvents@22$EKErrorCalendarDoesNotAllowReminders@23$EKErrorCalendarHasNoSource@14$EKErrorCalendarIsImmutable@16$EKErrorCalendarReadOnly@6$EKErrorCalendarSourceCannotBeModified@15$EKErrorDatesInverted@4$EKErrorDurationGreaterThanRecurrence@7$EKErrorEventNotMutable@0$EKErrorEventStoreNotAuthorized@29$EKErrorInternalFailure@5$EKErrorInvalidEntityType@27$EKErrorInvalidInviteReplyCalendar@31$EKErrorInvalidSpan@13$EKErrorInvitesCannotBeMoved@12$EKErrorLast@31$EKErrorNoCalendar@1$EKErrorNoEndDate@3$EKErrorNoStartDate@2$EKErrorNotificationCollectionMismatch@34$EKErrorNotificationSavedWithoutCollection@35$EKErrorNotificationsCollectionFlagNotSet@32$EKErrorOSNotSupported@30$EKErrorObjectBelongsToDifferentStore@11$EKErrorPriorityIsInvalid@26$EKErrorProcedureAlarmsNotMutable@28$EKErrorRecurringReminderRequiresDueDate@18$EKErrorReminderLocationsNotSupported@20$EKErrorSourceDoesNotAllowCalendarAddDelete@17$EKErrorSourceDoesNotAllowEvents@25$EKErrorSourceDoesNotAllowReminders@24$EKErrorSourceMismatch@33$EKErrorStartDateCollidesWithOtherOccurrence@10$EKErrorStartDateTooFarInFuture@9$EKErrorStructuredLocationsNotSupported@19$EKEventAvailabilityBusy@0$EKEventAvailabilityFree@1$EKEventAvailabilityNotSupported@-1$EKEventAvailabilityTentative@2$EKEventAvailabilityUnavailable@3$EKEventStatusCanceled@3$EKEventStatusConfirmed@1$EKEventStatusNone@0$EKEventStatusTentative@2$EKFriday@6$EKMonday@2$EKParticipantRoleChair@3$EKParticipantRoleNonParticipant@4$EKParticipantRoleOptional@2$EKParticipantRoleRequired@1$EKParticipantRoleUnknown@0$EKParticipantScheduleStatusCannotDeliver@7$EKParticipantScheduleStatusDelivered@3$EKParticipantScheduleStatusDeliveryFailed@6$EKParticipantScheduleStatusNoPrivileges@5$EKParticipantScheduleStatusNone@0$EKParticipantScheduleStatusPending@1$EKParticipantScheduleStatusRecipientNotAllowed@8$EKParticipantScheduleStatusRecipientNotRecognized@4$EKParticipantScheduleStatusSent@2$EKParticipantStatusAccepted@2$EKParticipantStatusCompleted@6$EKParticipantStatusDeclined@3$EKParticipantStatusDelegated@5$EKParticipantStatusInProcess@7$EKParticipantStatusPending@1$EKParticipantStatusTentative@4$EKParticipantStatusUnknown@0$EKParticipantTypeGroup@4$EKParticipantTypePerson@1$EKParticipantTypeResource@3$EKParticipantTypeRoom@2$EKParticipantTypeUnknown@0$EKRecurrenceFrequencyDaily@0$EKRecurrenceFrequencyMonthly@2$EKRecurrenceFrequencyWeekly@1$EKRecurrenceFrequencyYearly@3$EKReminderPriorityHigh@1$EKReminderPriorityLow@9$EKReminderPriorityMedium@5$EKReminderPriorityNone@0$EKSaturday@7$EKSourceTypeBirthdays@5$EKSourceTypeCalDAV@2$EKSourceTypeExchange@1$EKSourceTypeLocal@0$EKSourceTypeMobileMe@3$EKSourceTypeSubscribed@4$EKSpanFutureEvents@1$EKSpanThisEvent@0$EKSunday@1$EKThursday@5$EKTuesday@3$EKWednesday@4$EKWeekdayFriday@6$EKWeekdayMonday@2$EKWeekdaySaturday@7$EKWeekdaySunday@1$EKWeekdayThursday@5$EKWeekdayTuesday@3$EKWeekdayWednesday@4$"""
misc.update({})
functions = {
    "DATE_COMPONENTS_DO_NOT_USE": (b"v",),
    "DATETIME_COMPONENTS_DO_NOT_USE": (b"v",),
    "EK_LOSE_FRACTIONAL_SECONDS_DO_NOT_USE": (b"v",),
}
aliases = {
    "EKWednesday": "EKWeekdayWednesday",
    "EKSunday": "EKWeekdaySunday",
    "EKFriday": "EKWeekdayFriday",
    "EKSaturday": "EKWeekdaySaturday",
    "EKTuesday": "EKWeekdayTuesday",
    "EKThursday": "EKWeekdayThursday",
    "EKMonday": "EKWeekdayMonday",
}
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(b"EKCalendar", b"allowsContentModifications", {"retval": {"type": b"Z"}})
    r(b"EKCalendar", b"isImmutable", {"retval": {"type": b"Z"}})
    r(b"EKCalendar", b"isSubscribed", {"retval": {"type": b"Z"}})
    r(b"EKCalendarItem", b"hasAlarms", {"retval": {"type": b"Z"}})
    r(b"EKCalendarItem", b"hasAttendees", {"retval": {"type": b"Z"}})
    r(b"EKCalendarItem", b"hasNotes", {"retval": {"type": b"Z"}})
    r(b"EKCalendarItem", b"hasRecurrenceRules", {"retval": {"type": b"Z"}})
    r(b"EKCalendarItem", b"isAllDay", {"retval": {"type": "Z"}})
    r(b"EKEvent", b"isAllDay", {"retval": {"type": b"Z"}})
    r(b"EKEvent", b"isDetached", {"retval": {"type": b"Z"}})
    r(b"EKEvent", b"refresh", {"retval": {"type": b"Z"}})
    r(b"EKEvent", b"setAllDay:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"EKEventStore",
        b"commit:",
        {"retval": {"type": b"Z"}, "arguments": {2: {"type_modifier": b"o"}}},
    )
    r(
        b"EKEventStore",
        b"enumerateEventsMatchingPredicate:usingBlock:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"o^B"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"EKEventStore",
        b"fetchRemindersMatchingPredicate:completion:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"EKEventStore",
        b"removeCalendar:commit:error:",
        {
            "retval": {"type": b"Z"},
            "arguments": {3: {"type": b"Z"}, 4: {"type_modifier": b"o"}},
        },
    )
    r(
        b"EKEventStore",
        b"removeEvent:span:commit:error:",
        {
            "retval": {"type": b"Z"},
            "arguments": {4: {"type": b"Z"}, 5: {"type_modifier": b"o"}},
        },
    )
    r(
        b"EKEventStore",
        b"removeEvent:span:error:",
        {"retval": {"type": b"Z"}, "arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"EKEventStore",
        b"removeReminder:commit:error:",
        {
            "retval": {"type": b"Z"},
            "arguments": {3: {"type": b"Z"}, 4: {"type_modifier": b"o"}},
        },
    )
    r(
        b"EKEventStore",
        b"requestAccessToEntityType:completion:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"Z"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"EKEventStore",
        b"saveCalendar:commit:error:",
        {
            "retval": {"type": b"Z"},
            "arguments": {3: {"type": b"Z"}, 4: {"type_modifier": b"o"}},
        },
    )
    r(
        b"EKEventStore",
        b"saveEvent:span:commit:error:",
        {
            "retval": {"type": b"Z"},
            "arguments": {4: {"type": b"Z"}, 5: {"type_modifier": b"o"}},
        },
    )
    r(
        b"EKEventStore",
        b"saveEvent:span:error:",
        {"retval": {"type": b"Z"}, "arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"EKEventStore",
        b"saveReminder:commit:error:",
        {
            "retval": {"type": b"Z"},
            "arguments": {3: {"type": b"Z"}, 4: {"type_modifier": b"o"}},
        },
    )
    r(b"EKObject", b"hasChanges", {"retval": {"type": b"Z"}})
    r(b"EKObject", b"isNew", {"retval": {"type": b"Z"}})
    r(b"EKObject", b"refresh", {"retval": {"type": b"Z"}})
    r(b"EKParticipant", b"isCurrentUser", {"retval": {"type": b"Z"}})
    r(b"EKReminder", b"isCompleted", {"retval": {"type": b"Z"}})
    r(b"EKReminder", b"setCompleted:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"EKVirtualConferenceProvider",
        b"fetchAvailableRoomTypesWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"EKVirtualConferenceProvider",
        b"fetchVirtualConferenceForIdentifier:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



from PyObjCTools.TestSupport import TestCase, min_os_level

import EventKit


class TestEKCalendarItem(TestCase):
    @min_os_level("10.8")
    def testBasic(self):
        self.assertTrue(hasattr(EventKit, "EKCalendarItem"))

    @min_os_level("10.8")
    def testMethods10_8(self):
        self.assertResultIsBOOL(EventKit.EKCalendarItem.hasAlarms)
        self.assertResultIsBOOL(EventKit.EKCalendarItem.hasAttendees)
        self.assertResultIsBOOL(EventKit.EKCalendarItem.hasNotes)
        self.assertResultIsBOOL(EventKit.EKCalendarItem.hasRecurrenceRules)



from PyObjCTools.TestSupport import TestCase, min_os_level
import EventKit


class TestEKRecurrenceRule(TestCase):
    @min_os_level("10.8")
    def testBasic(self):
        self.assertTrue(hasattr(EventKit, "EKRecurrenceRule"))

    @min_os_level("10.8")
    def testConstants10_8(self):
        self.assertEqual(EventKit.EKRecurrenceFrequencyDaily, 0)
        self.assertEqual(EventKit.EKRecurrenceFrequencyWeekly, 1)
        self.assertEqual(EventKit.EKRecurrenceFrequencyMonthly, 2)
        self.assertEqual(EventKit.EKRecurrenceFrequencyYearly, 3)

        self.assertEqual(EventKit.EKSunday, 1)
        self.assertEqual(EventKit.EKMonday, 2)
        self.assertEqual(EventKit.EKTuesday, 3)
        self.assertEqual(EventKit.EKWednesday, 4)
        self.assertEqual(EventKit.EKThursday, 5)
        self.assertEqual(EventKit.EKFriday, 6)
        self.assertEqual(EventKit.EKSaturday, 7)



from PyObjCTools.TestSupport import TestCase, min_os_level
import EventKit


class TestEKParticipant(TestCase):
    @min_os_level("10.8")
    def testBasic(self):
        self.assertTrue(hasattr(EventKit, "EKParticipant"))

    @min_os_level("10.9")
    def testMethods10_9(self):
        self.assertResultIsBOOL(EventKit.EKParticipant.isCurrentUser)

    @min_os_level("10.8")
    def testConstants10_8(self):
        self.assertEqual(EventKit.EKParticipantRoleUnknown, 0)
        self.assertEqual(EventKit.EKParticipantRoleRequired, 1)
        self.assertEqual(EventKit.EKParticipantRoleOptional, 2)
        self.assertEqual(EventKit.EKParticipantRoleChair, 3)
        self.assertEqual(EventKit.EKParticipantRoleNonParticipant, 4)

        self.assertEqual(EventKit.EKParticipantStatusUnknown, 0)
        self.assertEqual(EventKit.EKParticipantStatusPending, 1)
        self.assertEqual(EventKit.EKParticipantStatusAccepted, 2)
        self.assertEqual(EventKit.EKParticipantStatusDeclined, 3)
        self.assertEqual(EventKit.EKParticipantStatusTentative, 4)
        self.assertEqual(EventKit.EKParticipantStatusDelegated, 5)
        self.assertEqual(EventKit.EKParticipantStatusCompleted, 6)
        self.assertEqual(EventKit.EKParticipantStatusInProcess, 7)

        self.assertEqual(EventKit.EKParticipantTypeUnknown, 0)
        self.assertEqual(EventKit.EKParticipantTypePerson, 1)
        self.assertEqual(EventKit.EKParticipantTypeRoom, 2)
        self.assertEqual(EventKit.EKParticipantTypeResource, 3)
        self.assertEqual(EventKit.EKParticipantTypeGroup, 4)



from PyObjCTools.TestSupport import TestCase, min_os_level
import EventKit


class TestEKEvent(TestCase):
    @min_os_level("10.8")
    def testBasic(self):
        self.assertTrue(hasattr(EventKit, "EKObject"))

    @min_os_level("10.8")
    def testMethods10_8(self):
        self.assertResultIsBOOL(EventKit.EKObject.hasChanges)
        self.assertResultIsBOOL(EventKit.EKObject.isNew)
        self.assertResultIsBOOL(EventKit.EKObject.refresh)



from PyObjCTools.TestSupport import TestCase, min_os_level
import EventKit


class TestEKTypes(TestCase):
    @min_os_level("10.8")
    def testConstacts(self):
        self.assertEqual(EventKit.EKAlarmProximityLeave, 2)

        self.assertEqual(EventKit.EKAuthorizationStatusNotDetermined, 0)
        self.assertEqual(EventKit.EKAuthorizationStatusRestricted, 1)
        self.assertEqual(EventKit.EKAuthorizationStatusDenied, 2)
        self.assertEqual(EventKit.EKAuthorizationStatusAuthorized, 3)

        self.assertEqual(EventKit.EKWeekdaySunday, 1)
        self.assertEqual(EventKit.EKWeekdayMonday, 2)
        self.assertEqual(EventKit.EKWeekdayTuesday, 3)
        self.assertEqual(EventKit.EKWeekdayWednesday, 4)
        self.assertEqual(EventKit.EKWeekdayThursday, 5)
        self.assertEqual(EventKit.EKWeekdayFriday, 6)
        self.assertEqual(EventKit.EKWeekdaySaturday, 7)

        self.assertEqual(EventKit.EKSunday, EventKit.EKWeekdaySunday)
        self.assertEqual(EventKit.EKMonday, EventKit.EKWeekdayMonday)
        self.assertEqual(EventKit.EKTuesday, EventKit.EKWeekdayTuesday)
        self.assertEqual(EventKit.EKWednesday, EventKit.EKWeekdayWednesday)
        self.assertEqual(EventKit.EKThursday, EventKit.EKWeekdayThursday)
        self.assertEqual(EventKit.EKFriday, EventKit.EKWeekdayFriday)
        self.assertEqual(EventKit.EKSaturday, EventKit.EKWeekdaySaturday)

        self.assertEqual(EventKit.EKRecurrenceFrequencyDaily, 0)
        self.assertEqual(EventKit.EKRecurrenceFrequencyWeekly, 1)
        self.assertEqual(EventKit.EKRecurrenceFrequencyMonthly, 2)
        self.assertEqual(EventKit.EKRecurrenceFrequencyYearly, 3)

        self.assertEqual(EventKit.EKParticipantTypeUnknown, 0)
        self.assertEqual(EventKit.EKParticipantTypePerson, 1)
        self.assertEqual(EventKit.EKParticipantTypeRoom, 2)
        self.assertEqual(EventKit.EKParticipantTypeResource, 3)
        self.assertEqual(EventKit.EKParticipantTypeGroup, 4)

        self.assertEqual(EventKit.EKParticipantRoleUnknown, 0)
        self.assertEqual(EventKit.EKParticipantRoleRequired, 1)
        self.assertEqual(EventKit.EKParticipantRoleOptional, 2)
        self.assertEqual(EventKit.EKParticipantRoleChair, 3)
        self.assertEqual(EventKit.EKParticipantRoleNonParticipant, 4)

        self.assertEqual(EventKit.EKParticipantScheduleStatusNone, 0)
        self.assertEqual(EventKit.EKParticipantScheduleStatusPending, 1)
        self.assertEqual(EventKit.EKParticipantScheduleStatusSent, 2)
        self.assertEqual(EventKit.EKParticipantScheduleStatusDelivered, 3)
        self.assertEqual(EventKit.EKParticipantScheduleStatusRecipientNotRecognized, 4)
        self.assertEqual(EventKit.EKParticipantScheduleStatusNoPrivileges, 5)
        self.assertEqual(EventKit.EKParticipantScheduleStatusDeliveryFailed, 6)
        self.assertEqual(EventKit.EKParticipantScheduleStatusCannotDeliver, 7)
        self.assertEqual(EventKit.EKParticipantScheduleStatusRecipientNotAllowed, 8)

        self.assertEqual(EventKit.EKParticipantStatusUnknown, 0)
        self.assertEqual(EventKit.EKParticipantStatusPending, 1)
        self.assertEqual(EventKit.EKParticipantStatusAccepted, 2)
        self.assertEqual(EventKit.EKParticipantStatusDeclined, 3)
        self.assertEqual(EventKit.EKParticipantStatusTentative, 4)
        self.assertEqual(EventKit.EKParticipantStatusDelegated, 5)
        self.assertEqual(EventKit.EKParticipantStatusCompleted, 6)
        self.assertEqual(EventKit.EKParticipantStatusInProcess, 7)

        self.assertEqual(EventKit.EKCalendarTypeLocal, 0)
        self.assertEqual(EventKit.EKCalendarTypeCalDAV, 1)
        self.assertEqual(EventKit.EKCalendarTypeExchange, 2)
        self.assertEqual(EventKit.EKCalendarTypeSubscription, 3)
        self.assertEqual(EventKit.EKCalendarTypeBirthday, 4)

        self.assertEqual(EventKit.EKCalendarEventAvailabilityNone, 0)
        self.assertEqual(EventKit.EKCalendarEventAvailabilityBusy, (1 << 0))
        self.assertEqual(EventKit.EKCalendarEventAvailabilityFree, (1 << 1))
        self.assertEqual(EventKit.EKCalendarEventAvailabilityTentative, (1 << 2))
        self.assertEqual(EventKit.EKCalendarEventAvailabilityUnavailable, (1 << 3))

        self.assertEqual(EventKit.EKSourceTypeLocal, 0)
        self.assertEqual(EventKit.EKSourceTypeExchange, 1)
        self.assertEqual(EventKit.EKSourceTypeCalDAV, 2)
        self.assertEqual(EventKit.EKSourceTypeMobileMe, 3)
        self.assertEqual(EventKit.EKSourceTypeSubscribed, 4)
        self.assertEqual(EventKit.EKSourceTypeBirthdays, 5)

        self.assertEqual(EventKit.EKEntityTypeEvent, 0)
        self.assertEqual(EventKit.EKEntityTypeReminder, 1)

        self.assertEqual(EventKit.EKEntityMaskEvent, (1 << EventKit.EKEntityTypeEvent))
        self.assertEqual(
            EventKit.EKEntityMaskReminder, (1 << EventKit.EKEntityTypeReminder)
        )

        self.assertEqual(EventKit.EKAlarmProximityNone, 0)
        self.assertEqual(EventKit.EKAlarmProximityEnter, 1)
        self.assertEqual(EventKit.EKAlarmProximityLeave, 2)

        self.assertEqual(EventKit.EKAlarmTypeDisplay, 0)
        self.assertEqual(EventKit.EKAlarmTypeAudio, 1)
        self.assertEqual(EventKit.EKAlarmTypeProcedure, 2)
        self.assertEqual(EventKit.EKAlarmTypeEmail, 3)

        self.assertEqual(EventKit.EKReminderPriorityNone, 0)
        self.assertEqual(EventKit.EKReminderPriorityHigh, 1)
        self.assertEqual(EventKit.EKReminderPriorityMedium, 5)
        self.assertEqual(EventKit.EKReminderPriorityLow, 9)



from PyObjCTools.TestSupport import TestCase, min_os_level
import EventKit


class TestEKAlarm(TestCase):
    @min_os_level("10.8")
    def testConstants10_8(self):
        self.assertIsInstance(EventKit.EKErrorDomain, str)

        self.assertEqual(EventKit.EKErrorEventNotMutable, 0)
        self.assertEqual(EventKit.EKErrorNoCalendar, 1)
        self.assertEqual(EventKit.EKErrorNoStartDate, 2)
        self.assertEqual(EventKit.EKErrorNoEndDate, 3)
        self.assertEqual(EventKit.EKErrorDatesInverted, 4)
        self.assertEqual(EventKit.EKErrorInternalFailure, 5)
        self.assertEqual(EventKit.EKErrorCalendarReadOnly, 6)
        self.assertEqual(EventKit.EKErrorDurationGreaterThanRecurrence, 7)
        self.assertEqual(EventKit.EKErrorAlarmGreaterThanRecurrence, 8)
        self.assertEqual(EventKit.EKErrorStartDateTooFarInFuture, 9)
        self.assertEqual(EventKit.EKErrorStartDateCollidesWithOtherOccurrence, 10)
        self.assertEqual(EventKit.EKErrorObjectBelongsToDifferentStore, 11)
        self.assertEqual(EventKit.EKErrorInvitesCannotBeMoved, 12)
        self.assertEqual(EventKit.EKErrorInvalidSpan, 13)
        self.assertEqual(EventKit.EKErrorCalendarHasNoSource, 14)
        self.assertEqual(EventKit.EKErrorCalendarSourceCannotBeModified, 15)
        self.assertEqual(EventKit.EKErrorCalendarIsImmutable, 16)
        self.assertEqual(EventKit.EKErrorSourceDoesNotAllowCalendarAddDelete, 17)
        self.assertEqual(EventKit.EKErrorRecurringReminderRequiresDueDate, 18)
        self.assertEqual(EventKit.EKErrorStructuredLocationsNotSupported, 19)
        self.assertEqual(EventKit.EKErrorReminderLocationsNotSupported, 20)
        self.assertEqual(EventKit.EKErrorAlarmProximityNotSupported, 21)
        self.assertEqual(EventKit.EKErrorCalendarDoesNotAllowEvents, 22)
        self.assertEqual(EventKit.EKErrorCalendarDoesNotAllowReminders, 23)
        self.assertEqual(EventKit.EKErrorSourceDoesNotAllowReminders, 24)
        self.assertEqual(EventKit.EKErrorSourceDoesNotAllowEvents, 25)
        self.assertEqual(EventKit.EKErrorPriorityIsInvalid, 26)
        self.assertEqual(EventKit.EKErrorInvalidEntityType, 27)
        self.assertEqual(EventKit.EKErrorProcedureAlarmsNotMutable, 28)
        self.assertEqual(EventKit.EKErrorEventStoreNotAuthorized, 29)
        self.assertEqual(EventKit.EKErrorOSNotSupported, 30)
        self.assertEqual(EventKit.EKErrorInvalidInviteReplyCalendar, 31)
        self.assertEqual(EventKit.EKErrorNotificationsCollectionFlagNotSet, 32)
        self.assertEqual(EventKit.EKErrorSourceMismatch, 33)
        self.assertEqual(EventKit.EKErrorNotificationCollectionMismatch, 34)
        self.assertEqual(EventKit.EKErrorNotificationSavedWithoutCollection, 35)

        self.assertEqual(EventKit.EKErrorLast, 31)



from PyObjCTools.TestSupport import TestCase, min_os_level
import EventKit


class TestEKEvent(TestCase):
    @min_os_level("10.8")
    def testBasic(self):
        self.assertTrue(hasattr(EventKit, "EKEvent"))

    @min_os_level("10.8")
    def testMethods10_8(self):
        self.assertResultIsBOOL(EventKit.EKEvent.isAllDay)
        self.assertResultIsBOOL(EventKit.EKEvent.isDetached)
        self.assertResultIsBOOL(EventKit.EKEvent.refresh)

    @min_os_level("10.8")
    def testConstants10_8(self):
        self.assertEqual(EventKit.EKEventAvailabilityNotSupported, -1)
        self.assertEqual(EventKit.EKEventAvailabilityBusy, 0)
        self.assertEqual(EventKit.EKEventAvailabilityFree, 1)
        self.assertEqual(EventKit.EKEventAvailabilityTentative, 2)
        self.assertEqual(EventKit.EKEventAvailabilityUnavailable, 3)

        self.assertEqual(EventKit.EKEventStatusNone, 0)
        self.assertEqual(EventKit.EKEventStatusConfirmed, 1)
        self.assertEqual(EventKit.EKEventStatusTentative, 2)
        self.assertEqual(EventKit.EKEventStatusCanceled, 3)



from PyObjCTools.TestSupport import TestCase, min_os_level
import EventKit


class TestEKSource(TestCase):
    @min_os_level("10.8")
    def testBasic(self):
        self.assertTrue(hasattr(EventKit, "EKSource"))

    @min_os_level("10.8")
    def testConstants10_8(self):
        self.assertEqual(EventKit.EKSourceTypeLocal, 0)
        self.assertEqual(EventKit.EKSourceTypeExchange, 1)
        self.assertEqual(EventKit.EKSourceTypeCalDAV, 2)
        self.assertEqual(EventKit.EKSourceTypeMobileMe, 3)
        self.assertEqual(EventKit.EKSourceTypeSubscribed, 4)
        self.assertEqual(EventKit.EKSourceTypeBirthdays, 5)

        self.assertEqual(EventKit.EKEntityTypeEvent, 0)
        self.assertEqual(EventKit.EKEntityTypeReminder, 1)

        self.assertEqual(EventKit.EKEntityMaskEvent, (1 << EventKit.EKEntityTypeEvent))
        self.assertEqual(
            EventKit.EKEntityMaskReminder, (1 << EventKit.EKEntityTypeReminder)
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import EventKit


class TestEKCalendar(TestCase):
    @min_os_level("10.8")
    def testBasic(self):
        self.assertTrue(hasattr(EventKit, "EKCalendar"))

    @min_os_level("10.8")
    def testMethods10_8(self):
        self.assertResultIsBOOL(EventKit.EKCalendar.allowsContentModifications)
        self.assertResultIsBOOL(EventKit.EKCalendar.isImmutable)
        self.assertResultIsBOOL(EventKit.EKCalendar.isSubscribed)

    @min_os_level("10.8")
    def testConstants10_8(self):
        self.assertEqual(EventKit.EKCalendarTypeLocal, 0)
        self.assertEqual(EventKit.EKCalendarTypeCalDAV, 1)
        self.assertEqual(EventKit.EKCalendarTypeExchange, 2)
        self.assertEqual(EventKit.EKCalendarTypeSubscription, 3)
        self.assertEqual(EventKit.EKCalendarTypeBirthday, 4)

        self.assertEqual(EventKit.EKCalendarEventAvailabilityNone, 0)
        self.assertEqual(EventKit.EKCalendarEventAvailabilityBusy, 1 << 0)
        self.assertEqual(EventKit.EKCalendarEventAvailabilityFree, 1 << 1)
        self.assertEqual(EventKit.EKCalendarEventAvailabilityTentative, 1 << 2)
        self.assertEqual(EventKit.EKCalendarEventAvailabilityUnavailable, 1 << 3)



from PyObjCTools.TestSupport import TestCase, min_os_level
import EventKit


class TestEKVirtualConferenceProvider(TestCase):
    @min_os_level("12.0")
    def testMethods12_0(self):
        self.assertArgIsBlock(
            EventKit.EKVirtualConferenceProvider.fetchAvailableRoomTypesWithCompletionHandler_,
            0,
            b"v@@",
        )
        self.assertArgIsBlock(
            EventKit.EKVirtualConferenceProvider.fetchVirtualConferenceForIdentifier_completionHandler_,
            1,
            b"v@@",
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import EventKit


class TestEKAlarm(TestCase):
    @min_os_level("10.8")
    def testBasic(self):
        self.assertTrue(hasattr(EventKit, "EKAlarm"))

    @min_os_level("10.8")
    def testConstants10_8(self):
        self.assertEqual(EventKit.EKAlarmTypeDisplay, 0)
        self.assertEqual(EventKit.EKAlarmTypeAudio, 1)
        self.assertEqual(EventKit.EKAlarmTypeProcedure, 2)
        self.assertEqual(EventKit.EKAlarmTypeEmail, 3)

        self.assertEqual(EventKit.EKAlarmProximityNone, 0)
        self.assertEqual(EventKit.EKAlarmProximityEnter, 1)
        self.assertEqual(EventKit.EKAlarmProximityLeave, 2)



from PyObjCTools.TestSupport import TestCase, min_os_level
import EventKit


class TestEKReminder(TestCase):
    @min_os_level("10.8")
    def testBasic(self):
        self.assertTrue(hasattr(EventKit, "EKReminder"))

    @min_os_level("10.8")
    def testMethods10_8(self):
        self.assertResultIsBOOL(EventKit.EKReminder.isCompleted)
        self.assertArgIsBOOL(EventKit.EKReminder.setCompleted_, 0)

    def testConstants(self):
        self.assertEqual(EventKit.EKReminderPriorityNone, 0)
        self.assertEqual(EventKit.EKReminderPriorityHigh, 1)
        self.assertEqual(EventKit.EKReminderPriorityMedium, 5)
        self.assertEqual(EventKit.EKReminderPriorityLow, 9)



from PyObjCTools.TestSupport import TestCase, min_os_level
import EventKit


class TestEKEventStore(TestCase):
    @min_os_level("10.8")
    def testBasic(self):
        self.assertTrue(hasattr(EventKit, "EKEventStore"))

    @min_os_level("10.8")
    def testMethods10_8(self):
        self.assertResultIsBOOL(EventKit.EKEventStore.commit_)
        self.assertArgIsOut(EventKit.EKEventStore.commit_, 0)

        self.assertArgIsBlock(
            EventKit.EKEventStore.enumerateEventsMatchingPredicate_usingBlock_,
            1,
            b"v@o^B",
        )
        self.assertArgIsBlock(
            EventKit.EKEventStore.fetchRemindersMatchingPredicate_completion_, 1, b"v@"
        )

        self.assertResultIsBOOL(EventKit.EKEventStore.removeCalendar_commit_error_)
        self.assertArgIsBOOL(EventKit.EKEventStore.removeCalendar_commit_error_, 1)
        self.assertArgIsOut(EventKit.EKEventStore.removeCalendar_commit_error_, 2)

        self.assertResultIsBOOL(EventKit.EKEventStore.removeEvent_span_commit_error_)
        self.assertArgIsBOOL(EventKit.EKEventStore.removeEvent_span_commit_error_, 2)
        self.assertArgIsOut(EventKit.EKEventStore.removeEvent_span_commit_error_, 3)

        self.assertResultIsBOOL(EventKit.EKEventStore.removeReminder_commit_error_)
        self.assertArgIsBOOL(EventKit.EKEventStore.removeReminder_commit_error_, 1)
        self.assertArgIsOut(EventKit.EKEventStore.removeReminder_commit_error_, 2)

        self.assertResultIsBOOL(EventKit.EKEventStore.saveCalendar_commit_error_)
        self.assertArgIsBOOL(EventKit.EKEventStore.saveCalendar_commit_error_, 1)
        self.assertArgIsOut(EventKit.EKEventStore.saveCalendar_commit_error_, 2)

        self.assertResultIsBOOL(EventKit.EKEventStore.saveEvent_span_commit_error_)
        self.assertArgIsBOOL(EventKit.EKEventStore.saveEvent_span_commit_error_, 2)
        self.assertArgIsOut(EventKit.EKEventStore.saveEvent_span_commit_error_, 3)

        self.assertResultIsBOOL(EventKit.EKEventStore.saveReminder_commit_error_)
        self.assertArgIsBOOL(EventKit.EKEventStore.saveReminder_commit_error_, 1)
        self.assertArgIsOut(EventKit.EKEventStore.saveReminder_commit_error_, 2)

    @min_os_level("10.9")
    def testMethods10_9(self):
        self.assertArgIsBlock(
            EventKit.EKEventStore.requestAccessToEntityType_completion_, 1, b"vZ@"
        )

    @min_os_level("10.15")
    def testMethods10_14(self):
        self.assertResultIsBOOL(EventKit.EKEventStore.saveEvent_span_error_)
        self.assertArgIsOut(EventKit.EKEventStore.saveEvent_span_error_, 2)

        self.assertResultIsBOOL(EventKit.EKEventStore.removeEvent_span_error_)
        self.assertArgIsOut(EventKit.EKEventStore.removeEvent_span_error_, 2)

    @min_os_level("10.8")
    def testConstants10_8(self):
        self.assertEqual(EventKit.EKSpanThisEvent, 0)
        self.assertEqual(EventKit.EKSpanFutureEvents, 1)

        self.assertIsInstance(EventKit.EKEventStoreChangedNotification, str)

        self.assertEqual(EventKit.EKAuthorizationStatusNotDetermined, 0)
        self.assertEqual(EventKit.EKAuthorizationStatusRestricted, 1)
        self.assertEqual(EventKit.EKAuthorizationStatusDenied, 2)
        self.assertEqual(EventKit.EKAuthorizationStatusAuthorized, 3)
